==> presto-main-0.273-sources.jar: com/facebook/presto/sql/planner/iterative/rule/PruneTopNColumns.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.sql.planner.iterative.rule;

import com.facebook.presto.spi.plan.PlanNode;
import com.facebook.presto.spi.plan.PlanNodeIdAllocator;
import com.facebook.presto.spi.plan.TopNNode;
import com.facebook.presto.spi.relation.VariableReferenceExpression;
import com.facebook.presto.sql.planner.PlanVariableAllocator;
import com.google.common.collect.Streams;

import java.util.Optional;
import java.util.Set;

import static com.facebook.presto.sql.planner.iterative.rule.Util.restrictChildOutputs;
import static com.facebook.presto.sql.planner.plan.Patterns.topN;
import static com.google.common.collect.ImmutableSet.toImmutableSet;

public class PruneTopNColumns
        extends ProjectOffPushDownRule<TopNNode>
{
    public PruneTopNColumns()
    {
        super(topN());
    }

    @Override
    protected Optional<PlanNode> pushDownProjectOff(PlanNodeIdAllocator idAllocator, PlanVariableAllocator variableAllocator, TopNNode topNNode, Set<VariableReferenceExpression> referencedOutputs)
    {
        Set<VariableReferenceExpression> prunedTopNInputs = Streams.concat(
                referencedOutputs.stream(),
                topNNode.getOrderingScheme().getOrderByVariables().stream())
                .collect(toImmutableSet());

        return restrictChildOutputs(idAllocator, topNNode, prunedTopNInputs);
    }
}

==> presto-main-0.288-sources.jar: com/facebook/presto/sql/planner/iterative/rule/PruneTopNColumns.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.facebook.presto.sql.planner.iterative.rule;

import com.facebook.presto.spi.VariableAllocator;
import com.facebook.presto.spi.plan.PlanNode;
import com.facebook.presto.spi.plan.PlanNodeIdAllocator;
import com.facebook.presto.spi.plan.TopNNode;
import com.facebook.presto.spi.relation.VariableReferenceExpression;
import com.google.common.collect.Streams;

import java.util.Optional;
import java.util.Set;

import static com.facebook.presto.sql.planner.iterative.rule.Util.restrictChildOutputs;
import static com.facebook.presto.sql.planner.plan.Patterns.topN;
import static com.google.common.collect.ImmutableSet.toImmutableSet;

public class PruneTopNColumns
        extends ProjectOffPushDownRule<TopNNode>
{
    public PruneTopNColumns()
    {
        super(topN());
    }

    @Override
    protected Optional<PlanNode> pushDownProjectOff(PlanNodeIdAllocator idAllocator, VariableAllocator variableAllocator, TopNNode topNNode, Set<VariableReferenceExpression> referencedOutputs)
    {
        Set<VariableReferenceExpression> prunedTopNInputs = Streams.concat(
                referencedOutputs.stream(),
                topNNode.getOrderingScheme().getOrderByVariables().stream())
                .collect(toImmutableSet());

        return restrictChildOutputs(idAllocator, topNNode, prunedTopNInputs);
    }
}
